@@ -1,6 +1,7 @@
 use JE;
 use Digest::MD5 qw(md5 md5_hex);
 use Webqq::Client::Util qw(console);
+use Webqq::Encryption qw(pwd_encrypt);
 sub Webqq::Client::_login1{ 
     console "尝试进行登录(阶段1)...\n";
     my $self = shift;
@@ -19,39 +20,56 @@ sub Webqq::Client::_login1{
 
     }
     else{
-        console "客户端加密算法生成中，这可能会花费几分钟，请耐心等待...\n";
-        my $je;
-        if(defined $self->{je}){
-            $je = $self->{je};
-        }
-        else{
-            local $/ = undef;
-            $javascript = <DATA>;
-            $je = JE->new;
-            $je->eval($javascript); 
-            if($@){
-                console "客户端加密算法执行错误：$@\n";
-                return 0;
-            } 
-            $self->{je} = $je;
-        }
-        my $p = $je->eval(qq#
-            var p = '$self->{qq_param}{pwd}';
-            var salt = '$self->{qq_param}{md5_salt}';
-            var verifycode = '$self->{qq_param}{verifycode}'; 
-            var r = \$.Encryption.getEncryption(p,salt,verifycode,1);
-            return(r);
-        #);
-
-        if($p and !$@){
-            $passwd  = $p;
-        }
-        else{
+        eval{
+            $passwd = pwd_encrypt($self->{qq_param}{pwd},$self->{qq_param}{md5_salt},$self->{qq_param}{verifycode},1) ;
+        };
+        if($@){
             console "客户端加密算法执行错误：$@\n";
-            return 0;
+            return 0; 
         }
-        
     }
+    #else{
+    #    console "客户端加密算法生成中，这可能会花费几分钟，请耐心等待...\n";
+    #    my $je;
+    #    if(defined $self->{je}){
+    #        $je = $self->{je};
+    #    }
+    #    else{
+    #        my $javascript;
+    #        if(defined $Webqq::Client::_javascript){
+    #            $javascript = $Webqq::Client::_javascript;
+    #        }
+    #        else{
+    #            local $/ = undef;
+    #            $javascript = <DATA>;
+    #            $Webqq::Client::_javascript = $javascript;
+    #            close DATA;
+    #        }
+    #        $je = JE->new;
+    #        $je->eval($javascript); 
+    #        if($@){
+    #            console "客户端加密算法执行错误：$@\n";
+    #            return 0;
+    #        } 
+    #        $self->{je} = $je;
+    #    }
+    #    my $p = $je->eval(qq#
+    #        var p = '$self->{qq_param}{pwd}';
+    #        var salt = '$self->{qq_param}{md5_salt}';
+    #        var verifycode = '$self->{qq_param}{verifycode}'; 
+    #        var r = \$.Encryption.getEncryption(p,salt,verifycode,1);
+    #        return(r);
+    #    #);
+    #
+    #    if($p and !$@){
+    #        $passwd  = $p;
+    #    }
+    #    else{
+    #        console "客户端加密算法执行错误：$@\n";
+    #        return 0;
+    #    }
+    #    
+    #}
     my $query_string_ul = $self->{type} eq 'webqq'? 'http%3A%2F%2Fweb2.qq.com%2Floginproxy.html%3Flogin2qq%3D1%26webqq_type%3D10'
                         :                           'http%3A%2F%2Fw.qq.com%2Fproxy.html%3Flogin2qq%3D1%26webqq_type%3D10'       
                         ;
@@ -113,12 +131,12 @@ sub Webqq::Client::_login1{
                 return -1;
             }
             elsif($d{retcode} == 3){
-                console "您输入的帐号或密码不正确，客户端退出...\n";
-                exit;
+                console "您输入的帐号或密码不正确，客户端终止运行...\n";
+                $self->stop();
             }   
             elsif($d{retcode} != 0){
-                console "$d{status}，客户端退出...\n";
-                exit;
+                console "$d{status}，客户端终止运行...\n";
+                $self->stop();
             }
             $self->{qq_param}{api_check_sig} = $d{api_check_sig};
             $self->{qq_param}{ptwebqq} = $self->search_cookie('ptwebqq');
